pymarket.statistics.maximum\_traded\_volume module
==================================================

.. automodule:: pymarket.statistics.maximum_traded_volume
    :members:
    :undoc-members:
    :show-inheritance:
